#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include "index_html.h"  // In dieser Datei befindet sich die Steuerung Webseite

const char* ssid = "MainWlan";      // WLAN-Name,
const char* password = "Gehaim"; // WLAN-Passwort
#define RelaisPin D4  // Relais 
#define TasterPin D1  // Aktiv Low (Taster zwischen TasterPin ung GND) 
int active_low = 1;   // "0" Relais schaltet bei +5V , "1" Relais beim schaltet bei 0V

ESP8266WebServer server(80);// Serverport  hier einstellen
int val = 0; 				// Hier wird der Schaltzustand gespeichert

void setup()
{
  pinMode(RelaisPin, OUTPUT);
  pinMode(TasterPin, INPUT_PULLUP);
  digitalWrite(RelaisPin, active_low);

  Serial.begin(115200);	// Serielle Schnittstelle initialisieren
  Serial.println("");	  // Neue Zeile
  Serial.println("Warte auf Verbindung");

  WiFi.mode(WIFI_AP);      // access point modus
  WiFi.softAP("astral", "12345678");  // Name des Wi-Fi Netzes und Passwort
  delay(500);           //Abwarten 0,5s
  Serial.print("IP Adresse ");  //Ausgabe aktueller IP des Servers
  Serial.println(WiFi.softAPIP());

 /* 
    // Mit Haus WLAN Verbinden
    WiFi.mode(WIFI_STA);
    WiFi.begin(ssid, password);
    // Warte auf verbindung
    while (WiFi.status() != WL_CONNECTED)
    {
    delay(500);
    Serial.print(".");
    }
    Serial.println("");
    Serial.print("Verbunden mit ");
    Serial.println(ssid);
    Serial.print("IP address: ");
    Serial.println(WiFi.localIP());
    // ENDE Mit Haus WLAN Verbinden
 */ 
//  Bechandlung der Ereignissen anschliessen
  server.on("/", Ereignis_Index);
  server.onNotFound ( handleNotFound );

  server.begin();  			// Starte den Server
  Serial.println("HTTP Server gestartet");
}

void loop()
{
  server.handleClient();
  if (!digitalRead(TasterPin)) // Wenn Taster betätigt "Signal 0"
  {
    val = !val;                // Umschalten
    digitalWrite(RelaisPin, active_low ^ val);  // Wenn active_low - Variable ist "1", das Zustand "val" wird invertiert
    Serial.println("Umschalten per Taster auf " + String(val));
    delay(500);       // Entprellung, Warten bis der Taster Kontakt sich beruhigt hat
    while (!digitalRead(TasterPin))server.handleClient(); // warten bis der Taster los gelassen wurde
  }
}

void Ereignis_Index()    // Wird ausgeführt wenn "http://<ip address>/" aufgerufen wurde
{
  if (server.args() > 0) // wenn Argumente im GET Anfrage vorhanden sind z.B http://<ip address>/?zustand=r
  {
    if (server.arg("relais") == "0")  // prüfen ob "/?relais=0"
    {
      Serial.println("Aus");
      val = 0;                        // Ausschalten
      digitalWrite(RelaisPin, active_low ^ val);
    }
    if (server.arg("relais") == "1")  // prüfen ob "/?relais=1"
    {
      Serial.println("Ein");
      val = 1;                        // Einschalten
      digitalWrite(RelaisPin, active_low ^ val);
    }
    if (server.arg("relais") == "2")  // prüfen ob "/?relais=2"  Toggle Funktion
    {
      val = !val;                     // Umschalten
      Serial.println("Umschalten auf " + String(val));
      digitalWrite(RelaisPin, active_low ^ val);
    }                                                  // es wird immer Relais Zushtand mitgeteilt
    server.sendHeader("Cache-Control", "no-cache");    // wichtig! damit Daten nicht aus dem Browser cach kommen
    server.send(200, "text/plain", String(int(val)) ); // Antwort an Internet Browser senden nur eine Zahl ("0"/"1")
  }
  else        // wenn keine Argumente im GET Anfrage
  {
    Serial.println("Sende Index.html");
    server.send(200, "text/html", indexHTML);           //dann Index Webseite senden (sehe Datei "index_html.h")
  }
}

void handleNotFound()
{
  server.send(404, "text/plain", "404: Not found");     // Send HTTP status 404 (Not Found)
}
